@@ -296,32 +296,38 @@ export const isStartOfThisWeek = (date: Date | number) => {
 };
 
 // Custom validator for "YYYY-MM-DD" format
-export const dateCustomValidation = z.string().refine(
-  (val: string) => {
-    const regex = /^\d{4}-\d{2}-\d{2}$/;
-    if (!regex.test(val)) return false;
+export const dateCustomValidation = z
+  .string()
+  .refine(
+    (val: string) => {
+      const regex = /^\d{4}-\d{2}-\d{2}$/;
+      if (!regex.test(val)) return false;
 
-    const date = new Date(val);
-    return isValid(date);
-  },
-  {
-    message: 'Invalid date format, expected YYYY-MM-DD',
-  },
-);
+      const date = new Date(val);
+      return isValid(date);
+    },
+    {
+      message: 'Invalid date format, expected YYYY-MM-DD',
+    },
+  )
+  .describe('__dateCustomValidation__');
 
 // Custom validator for "YYYY-MM-DD HH:MM:SS" format
-export const datetimeCustomValidation = z.string().refine(
-  (val: string) => {
-    const regex = /^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$/;
-    if (!regex.test(val)) return false;
+export const datetimeCustomValidation = z
+  .string()
+  .refine(
+    (val: string) => {
+      const regex = /^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$/;
+      if (!regex.test(val)) return false;
 
-    const date = new Date(val);
-    return isValid(date);
-  },
-  {
-    message: 'Invalid datetime format, expected YYYY-MM-DD HH:MM:SS',
-  },
-);
+      const date = new Date(val);
+      return isValid(date);
+    },
+    {
+      message: 'Invalid datetime format, expected YYYY-MM-DD HH:MM:SS',
+    },
+  )
+  .describe('__datetimeCustomValidation__');
 
 export const endpointsOfDay = (date: Date | number) => [startOfDay(date), endOfDay(date)];
 
